DROP DATABASE IF EXISTS endPointMonitor;
CREATE DATABASE IF NOT EXISTS endPointMonitor;

USE endPointMonitor;

CREATE USER IF NOT EXISTS 'endPointMonitorUser'@'%' IDENTIFIED BY '%password%' PASSWORD EXPIRE NEVER;
CREATE USER IF NOT EXISTS 'endPointMonitorAdmin'@'%' IDENTIFIED BY '%adminPassword%' PASSWORD EXPIRE NEVER;
GRANT SELECT, UPDATE, INSERT, DELETE, ALTER, CREATE, DROP, INDEX, REFERENCES ON endPointMonitor.* TO 'endPointMonitorAdmin'@'%';

SET sql_mode = '';

CREATE TABLE IF NOT EXISTS EPM_APIKEYS (
    id INTEGER NOT NULL AUTO_INCREMENT PRIMARY KEY,
    name VARCHAR(256) NOT NULL,
    readOnly BOOLEAN NOT NULL DEFAULT true,
    enabled BOOLEAN NOT NULL DEFAULT true,
    apiKey VARCHAR(64) NOT NULL,
    maskedKey VARCHAR(8) NOT NULL,
    lastInteractionTimestamp DATETIME NOT NULL DEFAULT '1970-01-01 00:00:00',
    lastUpdateTimestamp DATETIME NOT NULL DEFAULT now(),
    lastUpdateUserId INTEGER NOT NULL
);

CREATE TABLE IF NOT EXISTS EPM_DASHBOARDGROUPS (
    id BIGINT NOT NULL AUTO_INCREMENT PRIMARY KEY,
    name VARCHAR(256) NOT NULL,
    description VARCHAR(1024),
    alertEmailSubject VARCHAR(1024),
    alertEmailBody TEXT,
    archived BOOLEAN NOT NULL DEFAULT false,
    opsGenieKey VARCHAR(255),
    lastUpdateTimestamp DATETIME NOT NULL DEFAULT now(),
    lastUpdateUserId INTEGER NOT NULL
);

CREATE TABLE IF NOT EXISTS EPM_CHECKGROUPS (
    id BIGINT NOT NULL AUTO_INCREMENT PRIMARY KEY,
    name VARCHAR(256) NOT NULL,
    description VARCHAR(1024),
    dashboardGroupId BIGINT NOT NULL,
    archived BOOLEAN NOT NULL DEFAULT false,
    lastUpdateTimestamp DATETIME NOT NULL DEFAULT now(),
    lastUpdateUserId INTEGER NOT NULL
);

CREATE TABLE IF NOT EXISTS EPM_AUDITLOGENTRIES (
    id BIGINT NOT NULL AUTO_INCREMENT PRIMARY KEY,
    timestamp DATETIME NOT NULL DEFAULT now(),
    userId INTEGER NOT NULL,
    module VARCHAR(255) NOT NULL,
    message TEXT
);

CREATE TABLE IF NOT EXISTS EPM_AUTHENTICATIONSERVICECONFIG (
    id INTEGER NOT NULL AUTO_INCREMENT PRIMARY KEY,
    name VARCHAR(255) NOT NULL,
    type VARCHAR(64) NOT NULL,
    authenticationServiceId INTEGER NOT NULL,
	stringValue TEXT,
	integerValue INTEGER,
	doubleValue DECIMAL(18,5),
	booleanValue BOOLEAN,
	timestampValue DATETIME,
	secure BOOLEAN NOT NULL DEFAULT false
);

CREATE TABLE IF NOT EXISTS EPM_AUTHENTICATIONSERVICES (
    id INTEGER NOT NULL AUTO_INCREMENT PRIMARY KEY,
    name VARCHAR(256) NOT NULL,
    description VARCHAR(1024),
    type SMALLINT NOT NULL,
    enabled BOOLEAN NOT NULL DEFAULT true,
    mfaRequired BOOLEAN NOT NULL DEFAULT false,
    lastUpdateTimestamp DATETIME NOT NULL,
    lastUpdateUserId INTEGER NOT NULL
);

CREATE TABLE IF NOT EXISTS EPM_CHECKADDRESSES (
	id BIGINT NOT NULL AUTO_INCREMENT PRIMARY KEY,
	checkId BIGINT NOT NULL,
	address VARCHAR(64) NOT NULL
);

CREATE TABLE IF NOT EXISTS EPM_CHECKATTRIBUTES (
    id BIGINT NOT NULL AUTO_INCREMENT PRIMARY KEY,
    checkId BIGINT NOT NULL,
    name VARCHAR(1024) NOT NULL,
    type VARCHAR(64),
	stringValue VARCHAR(2048),
	integerValue INTEGER,
	decimalValue DECIMAL(18,5),
	booleanValue SMALLINT,
	timestampValue DATETIME
);

CREATE TABLE IF NOT EXISTS EPM_CHECKFAILUREMESSAGES (
    id BIGINT NOT NULL AUTO_INCREMENT PRIMARY KEY,
    checkResultId BIGINT NOT NULL,
    checkStepResultId BIGINT,
    message TEXT NOT NULL,
    status SMALLINT NOT NULL
);

CREATE TABLE IF NOT EXISTS EPM_CHECKHOSTGROUPS (
    id BIGINT NOT NULL AUTO_INCREMENT PRIMARY KEY,
    name VARCHAR(255) NOT NULL,
    description VARCHAR(1024),
    enabled BOOLEAN NOT NULL DEFAULT true,
    lastUpdateTimestamp DATETIME NOT NULL,
    lastUpdateUserId INTEGER NOT NULL
);

CREATE TABLE IF NOT EXISTS EPM_CHECKHOSTGROUPHOSTS (
    checkHostGroupId BIGINT NOT NULL,
    checkHostId BIGINT NOT NULL,
    PRIMARY KEY (checkHostGroupId, checkHostId)
);

CREATE TABLE IF NOT EXISTS EPM_CHECKHOSTS (
    id BIGINT NOT NULL AUTO_INCREMENT PRIMARY KEY,
    description VARCHAR(1024),
    hostname VARCHAR(255) NOT NULL,
    enabled BOOLEAN NOT NULL DEFAULT true,
    archived BOOLEAN NOT NULL DEFAULT false,
    maxConcurrentWebJourneyChecks INTEGER NOT NULL DEFAULT 2,
    type SMALLINT NOT NULL,
    lastCheckInTimestamp DATETIME NOT NULL,
    publicKey VARCHAR(2048),
    agentSendFiles BOOLEAN NOT NULL DEFAULT false,
    autoRegistered BOOLEAN NOT NULL DEFAULT false,
    version VARCHAR(32),
    lastUpdateTimestamp DATETIME NOT NULL,
    lastUpdateUserId INTEGER NOT NULL
);

CREATE TABLE IF NOT EXISTS EPM_CHECKREQUESTHEADERS(
    id BIGINT NOT NULL AUTO_INCREMENT PRIMARY KEY,
    checkId BIGINT NOT NULL,
    name VARCHAR(1024),
    value VARCHAR(1024)
);

CREATE TABLE IF NOT EXISTS EPM_CHECKRESULTS (
    id BIGINT NOT NULL AUTO_INCREMENT PRIMARY KEY,
    checkId BIGINT NOT NULL,
    checkTimestamp DATETIME NOT NULL,
    status SMALLINT NOT NULL,
    responseTime INTEGER,
    responseCode INTEGER,
    responseBodyFound BOOLEAN,
    queueDepth INTEGER,
    versionFound VARCHAR(255),
    resolvedAddress VARCHAR(128),
    daysRemaining INTEGER,
    maintenanceMode BOOLEAN NOT NULL DEFAULT false
);

CREATE TABLE IF NOT EXISTS EPM_CHECKS (
    id BIGINT NOT NULL AUTO_INCREMENT PRIMARY KEY,
    name VARCHAR(256) NOT NULL,
    description VARCHAR(1024),
    type VARCHAR(32) NOT NULL,
    enabled BOOLEAN NOT NULL DEFAULT true,
    archived BOOLEAN NOT NULL DEFAULT false,
    checkGroupId BIGINT NOT NULL,
    hostname VARCHAR(256) NOT NULL,
    alertFailureCount INTEGER NOT NULL,
    currentFailureCount INTEGER NOT NULL DEFAULT 0,
    lastResponse VARCHAR(32),
    status INTEGER NOT NULL DEFAULT 0,
    maintenanceOverride BOOLEAN NOT NULL DEFAULT false,
    checkFrequency INTEGER NOT NULL,
    lastCheckTimestamp DATETIME,
    lastUpdateTimestamp DATETIME NOT NULL DEFAULT now(),
    lastUpdateUserId INTEGER NOT NULL,
    correlationId VARCHAR(255),
    resultRetentionDays INTEGER NOT NULL,
    checkHostId BIGINT,
    checkHostGroupId BIGINT,
    lastScheduledTime DATETIME NOT NULL DEFAULT now(),
    nextCheckCounter BIGINT NOT NULL DEFAULT 0,
    lastFailureMessage TEXT
);

CREATE TABLE IF NOT EXISTS EPM_CHECKSCHEDULES (
    id BIGINT NOT NULL AUTO_INCREMENT PRIMARY KEY,
    checkId BIGINT NOT NULL,
    checkHostId BIGINT,
    checkHostGroupId BIGINT,
    associatedCheckHostId BIGINT,
    scheduledCheckTime DATETIME NOT NULL,
    webJourneyCheck BOOLEAN NOT NULL DEFAULT false,
    androidJourneyCheck BOOLEAN NOT NULL DEFAULT false,
    priority BOOLEAN NOT NULL DEFAULT false
);

CREATE TABLE IF NOT EXISTS EPM_CHECKSTRINGS (
    id BIGINT NOT NULL AUTO_INCREMENT PRIMARY KEY,
    checkId BIGINT NOT NULL,
    string VARCHAR(128) NOT NULL,
    comparator VARCHAR(32) NOT NULL
);

CREATE TABLE IF NOT EXISTS EPM_CONFIG (
	name VARCHAR(255) NOT NULL PRIMARY KEY,
	type VARCHAR(16) NOT NULL,
	stringValue TEXT,
	integerValue INTEGER,
	doubleValue DECIMAL(18,5),
	booleanValue BOOLEAN,
	timestampValue TIMESTAMP,
	timeValue TIME,
	dateValue DATE,
	secure BOOLEAN NOT NULL DEFAULT false,
	lastUpdateTimestamp DATETIME NOT NULL,
	lastUpdateUserId INTEGER NOT NULL
);

CREATE TABLE IF NOT EXISTS EPM_CONTROLLERPERMISSIONS (
	controllerId INTEGER NOT NULL,
	permissionId INTEGER NOT NULL,
	PRIMARY KEY (controllerId, permissionId)
);

CREATE TABLE IF NOT EXISTS EPM_CONTROLLERS (
	id INTEGER NOT NULL AUTO_INCREMENT PRIMARY KEY,
	path VARCHAR(1024)
);

CREATE TABLE IF NOT EXISTS EPM_DATABASE (
    name VARCHAR(255) NOT NULL PRIMARY KEY,
    type VARCHAR(16) NOT NULL,
	stringValue TEXT,
	integerValue INTEGER,
	doubleValue DECIMAL(18,5),
	booleanValue BOOLEAN,
	lastUpdateTimestamp DATETIME NOT NULL
);

CREATE TABLE IF NOT EXISTS EPM_EXPECTEDCONSOLEMESSAGES (
	id BIGINT NOT NULL AUTO_INCREMENT PRIMARY KEY,
	webJourneyStepId BIGINT,
	commonWebJourneyStepId BIGINT,
	message VARCHAR(512) NOT NULL,
	comparator VARCHAR(32) NOT NULL,
	logLevel VARCHAR(16) NOT NULL
);

CREATE TABLE IF NOT EXISTS EPM_EXPECTEDNETWORKREQUESTS (
	id BIGINT NOT NULL AUTO_INCREMENT,
	webJourneyStepId BIGINT,
	commonWebJourneyStepId BIGINT,
	url VARCHAR(255) NOT NULL,
	comparator VARCHAR(32) NOT NULL,
	warningResponseTime INTEGER,
	alertResponseTime INTEGER,
	expectedResponseCode INTEGER,
	anyClientError BOOLEAN NOT NULL,
	anyServerError BOOLEAN NOT NULL,
	anyInfoResponse BOOLEAN NOT NULL,
	anySuccessResponse BOOLEAN NOT NULL,
	anyRedirectResponse BOOLEAN NOT NULL,
	PRIMARY KEY (id)
);

CREATE TABLE IF NOT EXISTS EPM_EXPECTEDOBJECTS (
	id BIGINT NOT NULL AUTO_INCREMENT PRIMARY KEY,
	webJourneyStepId BIGINT,
	webPageInteractionId BIGINT,
	commonWebJourneyStepId BIGINT,
    xpath VARCHAR(255),
    searchString VARCHAR(255),
    elementId VARCHAR(255),
    elementName VARCHAR(255),
    elementType VARCHAR(255),
    content VARCHAR(1024),
    state VARCHAR(32),
    url VARCHAR(512),
    comparator VARCHAR(32),
    attributeName VARCHAR(255),
    attributeValue VARCHAR(255),
    componentId VARCHAR(255),
    componentType VARCHAR(255)
);

CREATE TABLE IF NOT EXISTS EPM_GROUPPERMISSIONS (
	groupId INTEGER NOT NULL,
	permissionId INTEGER NOT NULL,
	PRIMARY KEY (groupId, permissionId)
);

CREATE TABLE IF NOT EXISTS EPM_GROUPS (
    id INTEGER NOT NULL AUTO_INCREMENT PRIMARY KEY,
    name VARCHAR(256) NOT NULL,
    description VARCHAR(1024),
    enabled BOOLEAN NOT NULL DEFAULT true,
    lastUpdateTimestamp DATETIME NOT NULL,
    lastUpdateUserId INTEGER NOT NULL
);

CREATE TABLE IF NOT EXISTS EPM_MAINTENANCEPERIODS (
    id BIGINT NOT NULL AUTO_INCREMENT PRIMARY KEY,
    description VARCHAR(1024) NOT NULL,
    enabled BOOLEAN NOT NULL DEFAULT true,
    startTime TIME NOT NULL,
    endTime TIME NOT NULL,
    dayOfWeek INTEGER,
    lastUpdateTimestamp DATETIME NOT NULL DEFAULT now(),
    lastUpdateUserId INTEGER NOT NULL
);

CREATE TABLE IF NOT EXISTS EPM_MAINTENANCEPERIODCHECKS (
    maintenancePeriodId BIGINT NOT NULL,
    checkId BIGINT NOT NULL,
    PRIMARY KEY (maintenancePeriodId, checkId)
);

CREATE TABLE IF NOT EXISTS EPM_MAINTENANCEPERIODGROUPS (
    maintenancePeriodId BIGINT NOT NULL,
    checkGroupId BIGINT NOT NULL,
    PRIMARY KEY (maintenancePeriodId, checkGroupId)
);

CREATE TABLE IF NOT EXISTS EPM_MAINTENANCEPERIODCLUSTERS (
    maintenancePeriodId BIGINT NOT NULL,
    dashboardGroupId BIGINT NOT NULL,
    PRIMARY KEY (maintenancePeriodId, dashboardGroupId)
);

CREATE TABLE IF NOT EXISTS EPM_NODEACTIONS (
	id BIGINT NOT NULL AUTO_INCREMENT PRIMARY KEY,
	action VARCHAR(64) NOT NULL,
	checkHostId BIGINT NOT NULL,
	parameters VARCHAR(512),
	createdTimestamp TIMESTAMP NOT NULL DEFAULT now(),
	started BOOLEAN NOT NULL DEFAULT 0
);

CREATE TABLE IF NOT EXISTS EPM_NOTIFICATIONS (
    id BIGINT NOT NULL AUTO_INCREMENT PRIMARY KEY,
    name VARCHAR(255) NOT NULL,
    description VARCHAR(1024),
    type VARCHAR(32) NOT NULL,
    enabled BOOLEAN NOT NULL DEFAULT true,
    allChecks BOOLEAN NOT NULL DEFAULT false,
    allCheckTypes BOOLEAN NOT NULL DEFAULT false,
    allCheckGroups BOOLEAN NOT NULL DEFAULT false,
    allDashboardGroups BOOLEAN NOT NULL DEFAULT false,
    allCheckHosts BOOLEAN NOT NULL DEFAULT false,
    repeatNotifications BOOLEAN NOT NULL DEFAULT false,
    preAlertWarnings BOOLEAN NOT NULL DEFAULT false,
    sendResolved BOOLEAN NOT NULL DEFAULT true,
    lastUpdateTimestamp DATETIME NOT NULL DEFAULT now(),
    lastUpdateUserId INTEGER NOT NULL
);

CREATE TABLE IF NOT EXISTS EPM_NOTIFICATIONCHECKS (
    notificationId BIGINT NOT NULL,
    checkId BIGINT NOT NULL,
    PRIMARY KEY (notificationId, checkId)
);

CREATE TABLE IF NOT EXISTS EPM_NOTIFICATIONCHECKTYPES (
    notificationId BIGINT NOT NULL,
    checkType VARCHAR(32) NOT NULL,
    PRIMARY KEY (notificationId, checkType)
);

CREATE TABLE IF NOT EXISTS EPM_NOTIFICATIONGROUPS (
    notificationId BIGINT NOT NULL,
    checkGroupId BIGINT NOT NULL,
    PRIMARY KEY (notificationId, checkGroupId)
);

CREATE TABLE IF NOT EXISTS EPM_NOTIFICATIONCLUSTERS (
    notificationId BIGINT NOT NULL,
    dashboardGroupId BIGINT NOT NULL,
    PRIMARY KEY (notificationId, dashboardGroupId)
);

CREATE TABLE IF NOT EXISTS EPM_NOTIFICATIONCHECKHOSTS (
    notificationId BIGINT NOT NULL,
    checkHostId BIGINT NOT NULL,
    PRIMARY KEY (notificationId, checkHostId)
);

CREATE TABLE IF NOT EXISTS EPM_NOTIFICATIONEMAILADDRESSES (
    notificationId BIGINT NOT NULL,
    emailAddress VARCHAR(1024) NOT NULL
);

CREATE TABLE IF NOT EXISTS EPM_NOTIFICATIONHEADERS (
    notificationId BIGINT NOT NULL,
    name VARCHAR(1024) NOT NULL,
    value VARCHAR(1024) NOT NULL
);

CREATE TABLE IF NOT EXISTS EPM_NOTIFICATIONCONFIG (
    notificationId BIGINT NOT NULL,
    name VARCHAR(254) NOT NULL,
    type VARCHAR(64) NOT NULL,
    stringValue VARCHAR(1024),
    intValue INTEGER,
    doubleValue DOUBLE(18,5),
    booleanValue BOOLEAN,
    PRIMARY KEY (notificationId, name)
);

CREATE TABLE IF NOT EXISTS EPM_PERMISSIONS (
    id INTEGER NOT NULL AUTO_INCREMENT PRIMARY KEY,
    name VARCHAR(128) NOT NULL,
    description VARCHAR(255)
);

CREATE TABLE IF NOT EXISTS EPM_PROXYHOSTS (
    id INTEGER NOT NULL AUTO_INCREMENT PRIMARY KEY,
    name VARCHAR(256) NOT NULL,
    description VARCHAR(1024),
    hostname VARCHAR(256) NOT NULL,
    port SMALLINT NOT NULL,
    user VARCHAR(256),
    password VARCHAR(256),
    lastUpdateTimestamp DATETIME NOT NULL DEFAULT now(),
    lastUpdateUserId INTEGER NOT NULL
);

CREATE TABLE IF NOT EXISTS EPM_PUSHNOTIFICATIONS(
    id BIGINT NOT NULL AUTO_INCREMENT PRIMARY KEY,
    checkId BIGINT NOT NULL,
    timestamp TIMESTAMP NOT NULL,
    checkResultId BIGINT NOT NULL
);

CREATE TABLE IF NOT EXISTS EPM_USERS (
    id INTEGER NOT NULL AUTO_INCREMENT PRIMARY KEY,
    loginId VARCHAR(255) NOT NULL,
    name VARCHAR(255) NOT NULL,
    password VARCHAR(512),
    enabled BOOLEAN NOT NULL DEFAULT true,
    lastLoginTimestamp DATETIME,
    lastInteractionTimestamp DATETIME,
    sessionId VARCHAR(64),
    groupId INTEGER,
    authenticationServiceId INTEGER,
    failedLoginCount INTEGER NOT NULL DEFAULT 0,
    localPasswordExpire DATETIME,
    currentRequestToken VARCHAR(512),
    mfaKey VARCHAR(128),
    archived BOOLEAN NOT NULL DEFAULT false,
    lastUpdateTimestamp DATETIME NOT NULL,
    lastUpdateUserId INTEGER NOT NULL
);

CREATE TABLE IF NOT EXISTS EPM_USERSETTINGS (
    id BIGINT NOT NULL AUTO_INCREMENT PRIMARY KEY,
    userId INTEGER NOT NULL,
    name VARCHAR(255) NOT NULL,
    type VARCHAR(32) NOT NULL,
	stringValue TEXT,
	integerValue INTEGER,
	doubleValue DECIMAL(18,5),
	booleanValue BOOLEAN,
	timestampValue DATETIME
);

CREATE TABLE IF NOT EXISTS EPM_WEBJOURNEYCOMMONSTEPS (
    id BIGINT NOT NULL AUTO_INCREMENT PRIMARY KEY,
    name VARCHAR(255) NOT NULL,
    description TEXT,
	waitTime INTEGER NOT NULL,
	alertPageLoadTime INTEGER NOT NULL,
	warningPageLoadTime INTEGER NOT NULL,
	archived BOOLEAN DEFAULT false
);

CREATE TABLE IF NOT EXISTS EPM_WEBJOURNEYCONSOLELOGS (
    id BIGINT NOT NULL AUTO_INCREMENT PRIMARY KEY,
    checkResultId BIGINT NOT NULL,
    checkStepResultId BIGINT NOT NULL,
    timestamp DATETIME NOT NULL,
    level VARCHAR(16) NOT NULL,
    message TEXT
);

CREATE TABLE IF NOT EXISTS EPM_WEBJOURNEYMONITORDOMAINS (
    id BIGINT NOT NULL AUTO_INCREMENT PRIMARY KEY,
    checkId BIGINT NOT NULL,
    domain VARCHAR(255) NOT NULL,
    allowSubdomains BOOLEAN NOT NULL DEFAULT false
);

CREATE TABLE IF NOT EXISTS EPM_WEBJOURNEYPAGECHECKS (
    id BIGINT NOT NULL AUTO_INCREMENT PRIMARY KEY,
    webJourneyStepId BIGINT,
    commonWebJourneyStepId BIGINT,
    description VARCHAR(255) NOT NULL,
    type VARCHAR(32) NOT NULL,
    expectedObjectId BIGINT,
    expectedNetworkRequestId BIGINT,
    expectedConsoleMessageId BIGINT,
    warningOnly BOOLEAN NOT NULL DEFAULT false
);

CREATE TABLE IF NOT EXISTS EPM_CHECKSTEPRESULTFILES (
    id BIGINT NOT NULL AUTO_INCREMENT PRIMARY KEY,
    checkResultId BIGINT NOT NULL,
    checkStepResultId BIGINT NOT NULL,
    fileType VARCHAR(16) NOT NULL,
    filePath VARCHAR(255) NOT NULL,
    fileName VARCHAR(127) NOT NULL
);

CREATE TABLE IF NOT EXISTS EPM_CHECKSTEPRESULTS (
	id BIGINT NOT NULL AUTO_INCREMENT PRIMARY KEY,
	checkResultId BIGINT NOT NULL,
	webJourneyStepId BIGINT,
	androidJourneyStepId BIGINT,
	checkTimestamp DATETIME NOT NULL,
	status SMALLINT NOT NULL,
	failureReason TEXT,
	maintenanceMode BOOLEAN NOT NULL DEFAULT false
);

CREATE TABLE IF NOT EXISTS EPM_WEBJOURNEYSTEPS (
	id BIGINT NOT NULL AUTO_INCREMENT PRIMARY KEY,
	name VARCHAR(255),
	checkId BIGINT NOT NULL,
	stepNo INTEGER NOT NULL,
	waitTime INTEGER,
	alertPageLoadTime INTEGER,
	warningPageLoadTime INTEGER,
	archived BOOLEAN DEFAULT false,
	commonWebJourneyStepId BIGINT
);

CREATE TABLE IF NOT EXISTS EPM_WEBJOURNEYSUPPRESSIONS (
    id BIGINT NOT NULL AUTO_INCREMENT PRIMARY KEY,
    webJourneyStepId BIGINT,
    commonWebJourneyStepId BIGINT,
    description VARCHAR(255) NOT NULL,
    type VARCHAR(32) NOT NULL,
    expectedNetworkRequestId BIGINT,
    expectedConsoleMessageId BIGINT
);

CREATE TABLE IF NOT EXISTS EPM_WEBPAGEINTERACTIONS (
    id BIGINT NOT NULL AUTO_INCREMENT PRIMARY KEY,
    description VARCHAR(255) NOT NULL,
    webJourneyStepId BIGINT,
    commonWebJourneyStepId BIGINT,
    action VARCHAR(32) NOT NULL,
    inputText VARCHAR(255),
    inputPassword VARCHAR(255),
    alwaysRequired BOOLEAN NOT NULL,
    windowId SMALLINT,
    windowTitle VARCHAR(255),
    url VARCHAR(255),
    waitTime BIGINT,
    iframeId SMALLINT,
    iframeXpath VARCHAR(255),
    sequence INTEGER NOT NULL,
    selectOptionIndex INTEGER,
    selectOptionName VARCHAR(255),
    selectOptionValue VARCHAR(255),
    javascript TEXT
);

CREATE TABLE IF NOT EXISTS EPM_WEBPAGENETWORKREQUESTS (
	id BIGINT NOT NULL AUTO_INCREMENT PRIMARY KEY,
	webJourneyStepId BIGINT NOT NULL,
	checkResultId BIGINT NOT NULL,
	url TEXT NOT NULL,
	status INTEGER,
	requestTime INTEGER,
	dnsTime INTEGER,
	sslTime INTEGER,
	sslStatus VARCHAR(255),
	requestType VARCHAR(64) NOT NULL,
	timestamp DATETIME NOT NULL,
	checkId BIGINT NOT NULL
);

CREATE TABLE IF NOT EXISTS EPM_ANDROIDJOURNEYSTEPS (
	id BIGINT NOT NULL AUTO_INCREMENT PRIMARY KEY,
	name VARCHAR(255),
	checkId BIGINT NOT NULL,
	stepNo INTEGER NOT NULL,
	waitTime INTEGER,
	archived BOOLEAN DEFAULT false,
	commonAndroidJourneyStepId BIGINT
);

CREATE TABLE IF NOT EXISTS EPM_ANDROIDJOURNEYCOMMONSTEPS (
    id BIGINT NOT NULL AUTO_INCREMENT PRIMARY KEY,
    name VARCHAR(255) NOT NULL,
    description TEXT,
	waitTime INTEGER NOT NULL,
	archived BOOLEAN DEFAULT false
);

CREATE TABLE IF NOT EXISTS EPM_ANDROIDJOURNEYSTEPCHECKS (
    id BIGINT NOT NULL AUTO_INCREMENT PRIMARY KEY,
    androidJourneyStepId BIGINT,
    commonAndroidJourneyStepId BIGINT,
    description VARCHAR(255) NOT NULL,
    type VARCHAR(32) NOT NULL,
    expectedObjectId BIGINT,
    warningOnly BOOLEAN NOT NULL DEFAULT false
);

CREATE TABLE IF NOT EXISTS EPM_ANDROIDSTEPINTERACTIONS (
    id BIGINT NOT NULL AUTO_INCREMENT PRIMARY KEY,
    description VARCHAR(255) NOT NULL,
    androidJourneyStepId BIGINT,
    commonAndroidJourneyStepId BIGINT,
    sequence INTEGER NOT NULL,
    alwaysRequired BOOLEAN NOT NULL,
    action VARCHAR(32) NOT NULL,
    expectedObjectId BIGINT,
    inputText VARCHAR(255),
    inputPassword VARCHAR(255),
    waitTime BIGINT,
    screenRotation VARCHAR(32),
    swipeStartLocation VARCHAR(32),
    swipeDirection VARCHAR(16),
    swipeLength INTEGER,
    spinnerOptionIndex INTEGER,
    spinnerOptionText VARCHAR(256)
);

CREATE TABLE IF NOT EXISTS EPM_ANDROIDJOURNEYSTEPRESULTS (
	id BIGINT NOT NULL AUTO_INCREMENT PRIMARY KEY,
	checkResultId BIGINT NOT NULL,
	androidJourneyStepId BIGINT NOT NULL,
	checkTimestamp DATETIME NOT NULL,
	status SMALLINT NOT NULL,
	failureReason TEXT,
	maintenanceMode BOOLEAN NOT NULL DEFAULT false
);

CREATE TABLE IF NOT EXISTS EPM_ANDROIDJOURNEYSTEPRESULTFILES (
    id BIGINT NOT NULL AUTO_INCREMENT PRIMARY KEY,
    checkResultId BIGINT NOT NULL,
    androidJourneyStepResultId BIGINT NOT NULL,
    fileType VARCHAR(16) NOT NULL,
    filePath VARCHAR(255) NOT NULL,
    fileName VARCHAR(127) NOT NULL
);

ALTER TABLE EPM_ANDROIDJOURNEYSTEPCHECKS
	ADD CONSTRAINT EPM_ANDROIDJOURNEYSTEPCHECKS_FK01 FOREIGN KEY (androidJourneyStepId)
	REFERENCES EPM_ANDROIDJOURNEYSTEPS(id);

ALTER TABLE EPM_ANDROIDJOURNEYSTEPCHECKS
	ADD CONSTRAINT EPM_ANDROIDJOURNEYSTEPCHECKS_FK02 FOREIGN KEY (commonAndroidJourneyStepId)
	REFERENCES EPM_ANDROIDJOURNEYCOMMONSTEPS(id);

ALTER TABLE EPM_ANDROIDJOURNEYSTEPCHECKS
	ADD CONSTRAINT EPM_ANDROIDJOURNEYSTEPCHECKS_FK03 FOREIGN KEY (expectedObjectId)
	REFERENCES EPM_EXPECTEDOBJECTS(id);

ALTER TABLE EPM_ANDROIDJOURNEYSTEPRESULTFILES
	ADD CONSTRAINT EPM_ANDROIDJOURNEYSTEPRESULTFILES_FK01 FOREIGN KEY (checkResultId)
	REFERENCES EPM_CHECKRESULTS(id);

ALTER TABLE EPM_ANDROIDJOURNEYSTEPRESULTFILES
	ADD CONSTRAINT EPM_ANDROIDJOURNEYSTEPRESULTFILES_FK02 FOREIGN KEY (androidJourneyStepResultId)
	REFERENCES EPM_ANDROIDJOURNEYSTEPRESULTS(id);

ALTER TABLE EPM_ANDROIDJOURNEYSTEPRESULTS
	ADD CONSTRAINT EPM_ANDROIDJOURNEYSTEPRESULTS_FK01 FOREIGN KEY (checkResultId)
	REFERENCES EPM_CHECKRESULTS(id);

ALTER TABLE EPM_ANDROIDJOURNEYSTEPRESULTS
	ADD CONSTRAINT EPM_ANDROIDJOURNEYSTEPRESULTS_FK02 FOREIGN KEY (androidJourneyStepId)
	REFERENCES EPM_ANDROIDJOURNEYSTEPS(id);

ALTER TABLE EPM_ANDROIDJOURNEYSTEPS
	ADD CONSTRAINT EPM_ANDROIDJOURNEYSTEPS_FK01 FOREIGN KEY (checkId)
	REFERENCES EPM_CHECKS(id);

ALTER TABLE EPM_ANDROIDJOURNEYSTEPS
	ADD CONSTRAINT EPM_ANDROIDJOURNEYSTEPS_FK02 FOREIGN KEY (commonAndroidJourneyStepId)
	REFERENCES EPM_ANDROIDJOURNEYCOMMONSTEPS(id);

ALTER TABLE EPM_ANDROIDSTEPINTERACTIONS
	ADD CONSTRAINT EPM_ANDROIDSTEPINTERACTIONS_FK01 FOREIGN KEY (androidJourneyStepId)
	REFERENCES EPM_ANDROIDJOURNEYSTEPS(id);

ALTER TABLE EPM_ANDROIDSTEPINTERACTIONS
	ADD CONSTRAINT EPM_ANDROIDSTEPINTERACTIONS_FK02 FOREIGN KEY (commonAndroidJourneyStepId)
	REFERENCES EPM_ANDROIDJOURNEYCOMMONSTEPS(id);

ALTER TABLE EPM_ANDROIDSTEPINTERACTIONS
	ADD CONSTRAINT EPM_ANDROIDSTEPINTERACTIONS_FK03 FOREIGN KEY (expectedObjectId)
	REFERENCES EPM_EXPECTEDOBJECTS(id);

ALTER TABLE EPM_APIKEYS
	ADD CONSTRAINT EPM_APIKEYS_FK01 FOREIGN KEY (lastUpdateUserId)
	REFERENCES EPM_USERS(id);

ALTER TABLE EPM_DASHBOARDGROUPS
	ADD CONSTRAINT EPM_DASHBOARDGROUPS_FK01 FOREIGN KEY (lastUpdateUserId)
	REFERENCES EPM_USERS(id);

ALTER TABLE EPM_CHECKGROUPS
	ADD CONSTRAINT EPM_CHECKGROUPS_FK01 FOREIGN KEY (lastUpdateUserId)
	REFERENCES EPM_USERS(id);

ALTER TABLE EPM_CHECKGROUPS
	ADD CONSTRAINT EPM_CHECKGROUPS_FK02 FOREIGN KEY (dashboardGroupId)
	REFERENCES EPM_DASHBOARDGROUPS(id);

ALTER TABLE EPM_AUDITLOGENTRIES
	ADD CONSTRAINT EPM_AUDITLOGENTRIES_FK01 FOREIGN KEY (userId)
	REFERENCES EPM_USERS(id);

ALTER TABLE EPM_AUTHENTICATIONSERVICECONFIG
	ADD CONSTRAINT EPM_AUTHENTICATIONSERVICECONFIG_FK01 FOREIGN KEY (authenticationServiceId)
	REFERENCES EPM_AUTHENTICATIONSERVICES(id);

ALTER TABLE EPM_AUTHENTICATIONSERVICES
	ADD CONSTRAINT EPM_AUTHENTICATIONSERVICES_FK01 FOREIGN KEY (lastUpdateUserId)
	REFERENCES EPM_USERS(id);

ALTER TABLE EPM_CHECKADDRESSES
	ADD CONSTRAINT EPM_CHECKADDRESSES_FK01 FOREIGN KEY (checkId)
	REFERENCES EPM_CHECKS(id);

ALTER TABLE EPM_CHECKATTRIBUTES
	ADD CONSTRAINT EPM_CHECKATTRIBUTES_FK01 FOREIGN KEY (checkId)
	REFERENCES EPM_CHECKS(id);

ALTER TABLE EPM_CHECKFAILUREMESSAGES
	ADD CONSTRAINT EPM_CHECKFAILUREMESSAGES_FK01 FOREIGN KEY (checkResultId)
	REFERENCES EPM_CHECKRESULTS(id);

ALTER TABLE EPM_CHECKFAILUREMESSAGES
	ADD CONSTRAINT EPM_CHECKFAILUREMESSAGES_FK02 FOREIGN KEY (checkStepResultId)
	REFERENCES EPM_CHECKSTEPRESULTS(id);

ALTER TABLE EPM_CHECKHOSTGROUPS
	ADD CONSTRAINT EPM_CHECKHOSTGROUPS_FK01 FOREIGN KEY (lastUpdateUserId)
	REFERENCES EPM_USERS(id);

ALTER TABLE EPM_CHECKHOSTGROUPHOSTS
    ADD CONSTRAINT EPM_CHECKHOSTGROUPHOSTS_FK01 FOREIGN KEY (checkHostGroupId)
    REFERENCES EPM_CHECKHOSTGROUPS(id);

ALTER TABLE EPM_CHECKHOSTGROUPHOSTS
    ADD CONSTRAINT EPM_CHECKHOSTGROUPHOSTS_FK02 FOREIGN KEY (checkHostId)
    REFERENCES EPM_CHECKHOSTS(id);

ALTER TABLE EPM_CHECKHOSTS
	ADD CONSTRAINT EPM_CHECKHOSTS_FK01 FOREIGN KEY (lastUpdateUserId)
	REFERENCES EPM_USERS(id);

ALTER TABLE EPM_CHECKREQUESTHEADERS
	ADD CONSTRAINT EPM_CHECKREQUESTHEADERS_FK01 FOREIGN KEY (checkId)
	REFERENCES EPM_CHECKS(id);

ALTER TABLE EPM_CHECKRESULTS
	ADD CONSTRAINT EPM_CHECKRESULTS_FK01 FOREIGN KEY (checkId)
	REFERENCES EPM_CHECKS(id);

ALTER TABLE EPM_CHECKS
	ADD CONSTRAINT EPM_CHECKS_FK01 FOREIGN KEY (lastUpdateUserId)
	REFERENCES EPM_USERS(id);

ALTER TABLE EPM_CHECKS
	ADD CONSTRAINT EPM_CHECKS_FK02 FOREIGN KEY (checkHostId)
	REFERENCES EPM_CHECKHOSTS(id);

ALTER TABLE EPM_CHECKS
	ADD CONSTRAINT EPM_CHECKS_FK03 FOREIGN KEY (checkHostGroupId)
	REFERENCES EPM_CHECKHOSTGROUPS(id);

ALTER TABLE EPM_CHECKS
	ADD CONSTRAINT EPM_CHECKS_FK04 FOREIGN KEY (checkGroupId)
	REFERENCES EPM_CHECKGROUPS(id);

ALTER TABLE EPM_CHECKSCHEDULES
    ADD CONSTRAINT EPM_CHECKSCHEDULES_FK01 FOREIGN KEY (checkId)
    REFERENCES EPM_CHECKS(id);

ALTER TABLE EPM_CHECKSCHEDULES
    ADD CONSTRAINT EPM_CHECKSCHEDULES_FK02 FOREIGN KEY (checkHostId)
    REFERENCES EPM_CHECKHOSTS(id);

ALTER TABLE EPM_CHECKSCHEDULES
    ADD CONSTRAINT EPM_CHECKSCHEDULES_FK03 FOREIGN KEY (checkHostGroupId)
    REFERENCES EPM_CHECKHOSTGROUPS(id);

ALTER TABLE EPM_CHECKSCHEDULES
    ADD CONSTRAINT EPM_CHECKSCHEDULES_FK04 FOREIGN KEY (associatedCheckHostId)
    REFERENCES EPM_CHECKHOSTS(id);

ALTER TABLE EPM_CONTROLLERPERMISSIONS
	ADD CONSTRAINT EPM_CONTROLLERPERMISSIONS_FK01 FOREIGN KEY (controllerId)
	REFERENCES EPM_CONTROLLERS(id);

ALTER TABLE EPM_CONTROLLERPERMISSIONS
	ADD CONSTRAINT EPM_CONTROLLERPERMISSIONS_FK02 FOREIGN KEY (permissionId)
	REFERENCES EPM_PERMISSIONS(id);

ALTER TABLE EPM_EXPECTEDCONSOLEMESSAGES
	ADD CONSTRAINT EPM_EXPECTEDCONSOLEMESSAGES_FK01 FOREIGN KEY (webJourneyStepId)
	REFERENCES EPM_WEBJOURNEYSTEPS(id);

ALTER TABLE EPM_EXPECTEDCONSOLEMESSAGES
	ADD CONSTRAINT EPM_EXPECTEDCONSOLEMESSAGES_FK02 FOREIGN KEY (commonWebJourneyStepId)
	REFERENCES EPM_WEBJOURNEYCOMMONSTEPS(id);

ALTER TABLE EPM_EXPECTEDNETWORKREQUESTS
	ADD CONSTRAINT EPM_EXPECTEDNETWORKREQUESTS_FK01 FOREIGN KEY (webJourneyStepId)
	REFERENCES EPM_WEBJOURNEYSTEPS(id);

ALTER TABLE EPM_EXPECTEDNETWORKREQUESTS
	ADD CONSTRAINT EPM_EXPECTEDNETWORKREQUESTS_FK02 FOREIGN KEY (commonWebJourneyStepId)
	REFERENCES EPM_WEBJOURNEYSTEPS(id);

ALTER TABLE EPM_EXPECTEDOBJECTS
	ADD CONSTRAINT EPM_EXPECTEDOBJECTS_FK01 FOREIGN KEY (webJourneyStepId)
	REFERENCES EPM_WEBJOURNEYSTEPS(id);

ALTER TABLE EPM_EXPECTEDOBJECTS
	ADD CONSTRAINT EPM_EXPECTEDOBJECTS_FK02 FOREIGN KEY (webPageInteractionId)
	REFERENCES EPM_WEBPAGEINTERACTIONS(id);

ALTER TABLE EPM_EXPECTEDOBJECTS
    ADD CONSTRAINT EPM_EXPECTEDOBJECTS_FK03 FOREIGN KEY (commonWebJourneyStepId)
    REFERENCES EPM_WEBJOURNEYCOMMONSTEPS(id);

ALTER TABLE EPM_GROUPPERMISSIONS
	ADD CONSTRAINT EPM_GROUPPERMISSIONS_FK01 FOREIGN KEY (groupId)
	REFERENCES EPM_GROUPS(id);

ALTER TABLE EPM_GROUPPERMISSIONS
	ADD CONSTRAINT EPM_GROUPPERMISSIONS_FK02 FOREIGN KEY (permissionId)
	REFERENCES EPM_PERMISSIONS(id);

ALTER TABLE EPM_GROUPS
	ADD CONSTRAINT EPM_GROUPS_FK01 FOREIGN KEY (lastUpdateUserId)
	REFERENCES EPM_USERS(id);

ALTER TABLE EPM_MAINTENANCEPERIODS
	ADD CONSTRAINT EPM_MAINTENANCEPERIODS_FK01 FOREIGN KEY (lastUpdateUserId)
	REFERENCES EPM_USERS(id);

ALTER TABLE EPM_MAINTENANCEPERIODCHECKS
    ADD CONSTRAINT EPM_MAINTENANCEPERIODCHECKS_FK01 FOREIGN KEY (maintenancePeriodId)
    REFERENCES EPM_MAINTENANCEPERIODS(id);

ALTER TABLE EPM_MAINTENANCEPERIODCHECKS
    ADD CONSTRAINT EPM_MAINTENANCEPERIODCHECKS_FK02 FOREIGN KEY (checkId)
    REFERENCES EPM_CHECKS(id);

ALTER TABLE EPM_MAINTENANCEPERIODGROUPS
    ADD CONSTRAINT EPM_MAINTENANCEPERIODGROUPS_FK01 FOREIGN KEY (maintenancePeriodId)
    REFERENCES EPM_MAINTENANCEPERIODS(id);

ALTER TABLE EPM_MAINTENANCEPERIODGROUPS
    ADD CONSTRAINT EPM_MAINTENANCEPERIODGROUPS_FK02 FOREIGN KEY (checkGroupId)
    REFERENCES EPM_CHECKGROUPS(id);

ALTER TABLE EPM_MAINTENANCEPERIODCLUSTERS
    ADD CONSTRAINT EPM_MAINTENANCEPERIODCLUSTERS_FK01 FOREIGN KEY (maintenancePeriodId)
    REFERENCES EPM_MAINTENANCEPERIODS(id);

ALTER TABLE EPM_MAINTENANCEPERIODCLUSTERS
    ADD CONSTRAINT EPM_MAINTENANCEPERIODCLUSTERS_FK02 FOREIGN KEY (dashboardGroupId)
    REFERENCES EPM_DASHBOARDGROUPS(id);

ALTER TABLE EPM_NODEACTIONS
	ADD CONSTRAINT EPM_NODEACTIONS_FK01 FOREIGN KEY (checkHostId)
	REFERENCES EPM_CHECKHOSTS(id);

ALTER TABLE EPM_NOTIFICATIONS
    ADD CONSTRAINT EPM_NOTIFICATIONS_FK01 FOREIGN KEY (lastUpdateUserId)
    REFERENCES EPM_USERS(id);

ALTER TABLE EPM_NOTIFICATIONCHECKS
    ADD CONSTRAINT EPM_NOTIFICATIONCHECKS_FK01 FOREIGN KEY (notificationId)
    REFERENCES EPM_NOTIFICATIONS(id);

ALTER TABLE EPM_NOTIFICATIONCHECKS
    ADD CONSTRAINT EPM_NOTIFICATIONCHECKS_FK02 FOREIGN KEY (checkId)
    REFERENCES EPM_CHECKS(id);

ALTER TABLE EPM_NOTIFICATIONCHECKTYPES
    ADD CONSTRAINT EPM_NOTIFICATIONCHECKTYPES_FK01 FOREIGN KEY (notificationId)
    REFERENCES EPM_NOTIFICATIONS(id);

ALTER TABLE EPM_NOTIFICATIONGROUPS
    ADD CONSTRAINT EPM_NOTIFICATIONGROUPS_FK01 FOREIGN KEY (notificationId)
    REFERENCES EPM_NOTIFICATIONS(id);

ALTER TABLE EPM_NOTIFICATIONGROUPS
    ADD CONSTRAINT EPM_NOTIFICATIONGROUPS_FK02 FOREIGN KEY (checkGroupId)
    REFERENCES EPM_CHECKGROUPS(id);

ALTER TABLE EPM_NOTIFICATIONCLUSTERS
    ADD CONSTRAINT EPM_NOTIFICATIONCLUSTERS_FK01 FOREIGN KEY (notificationId)
    REFERENCES EPM_NOTIFICATIONS(id);

ALTER TABLE EPM_NOTIFICATIONCLUSTERS
    ADD CONSTRAINT EPM_NOTIFICATIONCLUSTERS_FK02 FOREIGN KEY (dashboardGroupId)
    REFERENCES EPM_DASHBOARDGROUPS(id);

ALTER TABLE EPM_NOTIFICATIONCHECKHOSTS
    ADD CONSTRAINT EPM_NOTIFICATIONCHECKHOSTS_FK01 FOREIGN KEY (notificationId)
    REFERENCES EPM_NOTIFICATIONS(id);

ALTER TABLE EPM_NOTIFICATIONCHECKHOSTS
    ADD CONSTRAINT EPM_NOTIFICATIONCHECKHOSTS_FK02 FOREIGN KEY (checkHostId)
    REFERENCES EPM_CHECKHOSTS(id);

ALTER TABLE EPM_NOTIFICATIONEMAILADDRESSES
    ADD CONSTRAINT EPM_NOTIFICATIONEMAILADDRESSES_FK01 FOREIGN KEY (notificationId)
    REFERENCES EPM_NOTIFICATIONS(id);

ALTER TABLE EPM_NOTIFICATIONCONFIG
    ADD CONSTRAINT EPM_NOTIFICATIONCONFIG_FK01 FOREIGN KEY (notificationId)
    REFERENCES EPM_NOTIFICATIONS(id);

ALTER TABLE EPM_NOTIFICATIONHEADERS
    ADD CONSTRAINT EPM_NOTIFICATIONHEADERS_FK01 FOREIGN KEY (notificationId)
    REFERENCES EPM_NOTIFICATIONS(id);

ALTER TABLE EPM_PROXYHOSTS
	ADD CONSTRAINT EPM_PROXYHOSTS_FK01 FOREIGN KEY (lastUpdateUserId)
	REFERENCES EPM_USERS(id);

ALTER TABLE EPM_PUSHNOTIFICATIONS
	ADD CONSTRAINT EPM_PUSHNOTIFICATIONS_FK01 FOREIGN KEY (checkId)
	REFERENCES EPM_CHECKS(id);

ALTER TABLE EPM_PUSHNOTIFICATIONS
	ADD CONSTRAINT EPM_PUSHNOTIFICATIONS_FK02 FOREIGN KEY (checkResultId)
	REFERENCES EPM_CHECKRESULTS(id);

ALTER TABLE EPM_USERSETTINGS
	ADD CONSTRAINT EPM_USERSETTINGS_FK01 FOREIGN KEY (userId)
	REFERENCES EPM_USERS(id);

ALTER TABLE EPM_WEBJOURNEYCONSOLELOGS
	ADD CONSTRAINT EPM_WEBJOURNEYCONSOLELOGS_FK01 FOREIGN KEY (checkResultId)
	REFERENCES EPM_CHECKRESULTS(id);

ALTER TABLE EPM_WEBJOURNEYCONSOLELOGS
	ADD CONSTRAINT EPM_WEBJOURNEYCONSOLELOGS_FK02 FOREIGN KEY (checkStepResultId)
	REFERENCES EPM_CHECKSTEPRESULTS(id);

ALTER TABLE EPM_WEBJOURNEYMONITORDOMAINS
	ADD CONSTRAINT EPM_WEBJOURNEYMONITORDOMAINS_FK01 FOREIGN KEY (checkId)
	REFERENCES EPM_CHECKS(id);

ALTER TABLE EPM_WEBJOURNEYPAGECHECKS
	ADD CONSTRAINT EPM_WEBJOURNEYPAGECHECKS_FK01 FOREIGN KEY (webJourneyStepId)
	REFERENCES EPM_WEBJOURNEYSTEPS(id);

ALTER TABLE EPM_WEBJOURNEYPAGECHECKS
	ADD CONSTRAINT EPM_WEBJOURNEYPAGECHECKS_FK02 FOREIGN KEY (commonWebJourneyStepId)
	REFERENCES EPM_WEBJOURNEYCOMMONSTEPS(id);

ALTER TABLE EPM_CHECKSTEPRESULTFILES
	ADD CONSTRAINT EPM_CHECKSTEPRESULTFILES_FK01 FOREIGN KEY (checkResultId)
	REFERENCES EPM_CHECKRESULTS(id);

ALTER TABLE EPM_CHECKSTEPRESULTFILES
	ADD CONSTRAINT EPM_CHECKSTEPRESULTFILES_FK02 FOREIGN KEY (checkStepResultId)
	REFERENCES EPM_CHECKSTEPRESULTS(id);

ALTER TABLE EPM_CHECKSTEPRESULTS
	ADD CONSTRAINT EPM_CHECKSTEPRESULTS_FK01 FOREIGN KEY (checkResultId)
	REFERENCES EPM_CHECKRESULTS(id);

ALTER TABLE EPM_CHECKSTEPRESULTS
	ADD CONSTRAINT EPM_CHECKSTEPRESULTS_FK02 FOREIGN KEY (webJourneyStepId)
	REFERENCES EPM_WEBJOURNEYSTEPS(id);

ALTER TABLE EPM_CHECKSTEPRESULTS
	ADD CONSTRAINT EPM_CHECKSTEPRESULTS_FK03 FOREIGN KEY (androidJourneyStepId)
	REFERENCES EPM_ANDROIDJOURNEYSTEPS(id);

ALTER TABLE EPM_WEBJOURNEYSTEPS
	ADD CONSTRAINT EPM_WEBJOURNEYSTEPS_FK01 FOREIGN KEY (checkId)
	REFERENCES EPM_CHECKS(id);

ALTER TABLE EPM_WEBJOURNEYSTEPS
	ADD CONSTRAINT EPM_WEBJOURNEYSTEPS_FK02 FOREIGN KEY (commonWebJourneyStepId)
	REFERENCES EPM_WEBJOURNEYCOMMONSTEPS(id);

ALTER TABLE EPM_WEBJOURNEYSUPPRESSIONS
	ADD CONSTRAINT EPM_WEBJOURNEYSUPPRESSIONS_FK01 FOREIGN KEY (webJourneyStepId)
	REFERENCES EPM_WEBJOURNEYSTEPS(id);

ALTER TABLE EPM_WEBJOURNEYSUPPRESSIONS
	ADD CONSTRAINT EPM_WEBJOURNEYSUPPRESSIONS_FK02 FOREIGN KEY (commonWebJourneyStepId)
	REFERENCES EPM_WEBJOURNEYCOMMONSTEPS(id);

ALTER TABLE EPM_WEBJOURNEYSUPPRESSIONS
	ADD CONSTRAINT EPM_WEBJOURNEYSUPPRESSIONS_FK03 FOREIGN KEY (expectedNetworkRequestId)
	REFERENCES EPM_EXPECTEDNETWORKREQUESTS(id);

ALTER TABLE EPM_WEBJOURNEYSUPPRESSIONS
	ADD CONSTRAINT EPM_WEBJOURNEYSUPPRESSIONS_FK04 FOREIGN KEY (expectedConsoleMessageId)
	REFERENCES EPM_EXPECTEDCONSOLEMESSAGES(id);

ALTER TABLE EPM_WEBPAGEINTERACTIONS
	ADD CONSTRAINT EPM_WEBPAGEINTERACTIONS_FK01 FOREIGN KEY (webJourneyStepId)
	REFERENCES EPM_WEBJOURNEYSTEPS(id);

ALTER TABLE EPM_WEBPAGEINTERACTIONS
	ADD CONSTRAINT EPM_WEBPAGEINTERACTIONS_FK02 FOREIGN KEY (commonWebJourneyStepId)
	REFERENCES EPM_WEBJOURNEYCOMMONSTEPS(id);

ALTER TABLE EPM_WEBPAGENETWORKREQUESTS
	ADD CONSTRAINT EPM_WEBPAGENETWORKREQUESTS_FK01 FOREIGN KEY (webJourneyStepId)
	REFERENCES EPM_WEBJOURNEYSTEPS(id);

ALTER TABLE EPM_WEBPAGENETWORKREQUESTS
	ADD CONSTRAINT EPM_WEBPAGENETWORKREQUESTS_FK02 FOREIGN KEY (checkResultId)
	REFERENCES EPM_CHECKRESULTS(id);

ALTER TABLE EPM_CHECKSTRINGS
    ADD CONSTRAINT EPM_CHECKSTRINGS_FK01 FOREIGN KEY (checkId)
    REFERENCES EPM_CHECKS(id);

CREATE INDEX EPM_DASHBOARDGROUPS_I01
	ON EPM_DASHBOARDGROUPS(archived);

CREATE INDEX EPM_CHECKGROUPS_I01
	ON EPM_CHECKGROUPS(archived);

CREATE INDEX EPM_AUTHENTICATIONSERVICECONFIG_I01
	ON EPM_AUTHENTICATIONSERVICECONFIG(id, name);

CREATE INDEX EPM_AUTHENTICATIONSERVICES_I01
	ON EPM_AUTHENTICATIONSERVICES(name);

CREATE INDEX EPM_CHECKATTRIBUTES_I01
    ON EPM_CHECKATTRIBUTES(name);

CREATE INDEX EPM_CHECKHOSTS_I02
    ON EPM_CHECKHOSTS(archived);

CREATE INDEX EPM_CHECKRESULTS_I01
    ON EPM_CHECKRESULTS(checkTimestamp);

CREATE INDEX EPM_CHECKS_I01
    ON EPM_CHECKS(archived);

CREATE INDEX EPM_CHECKSCHEDULES_I01
    ON EPM_CHECKSCHEDULES(scheduledCheckTime);

CREATE INDEX EPM_CHECKSCHEDULES_I02
    ON EPM_CHECKSCHEDULES(associatedCheckHostId);

CREATE INDEX EPM_USERS_I01
    ON EPM_USERS(loginId);

CREATE INDEX EPM_USERS_I02
    ON EPM_USERS(sessionId);

CREATE INDEX EPM_USERSETTINGS_I01
    ON EPM_USERSETTINGS(userId, name);

CREATE INDEX EPM_WEBJOURNEYSTEPS_I01
    ON EPM_WEBJOURNEYSTEPS(archived);

CREATE INDEX EPM_WEBPAGENETWORKREQUESTS_I01
    ON EPM_WEBPAGENETWORKREQUESTS(timestamp, checkId);

CREATE UNIQUE INDEX EPM_EXPECTEDOBJECTS_I01
    ON EPM_EXPECTEDOBJECTS(webPageInteractionId);




INSERT INTO EPM_USERS (name, loginId, password, enabled, lastUpdateUserId, lastUpdateTimestamp) VALUES ('EndPointMonitor', 'EndPointMonitor', 'disabled', true, 0, now());
UPDATE EPM_USERS SET id = 0 WHERE name = 'EndPointMonitor';

INSERT INTO EPM_AUTHENTICATIONSERVICES (id, name, description, enabled, type, lastUpdateUserId, lastUpdateTimestamp)
VALUES (1, 'Initial Setup Authentication Service', 'Initial Setup Authentication Service', 1, 2, 0, now());
UPDATE EPM_AUTHENTICATIONSERVICES SET id = 1 WHERE name = 'Initial Setup Authentication Service';

INSERT INTO EPM_GROUPS (name, description, enabled, lastUpdateTimestamp, lastUpdateUserId)
    VALUES ('Default User Group', 'Default user group.', true, now(), 0);
UPDATE EPM_GROUPS SET id = 1 WHERE name = 'Default User Group';

UPDATE EPM_USERS SET authenticationServiceId = 1, groupId = 1 WHERE id = 0;

ALTER TABLE EPM_USERS
	ADD FOREIGN KEY EPM_USERS_FK01 (lastUpdateUserId)
	REFERENCES EPM_USERS(id);

ALTER TABLE EPM_USERS
	ADD FOREIGN KEY EPM_USERS_FK02 (groupId)
	REFERENCES EPM_GROUPS(id);

ALTER TABLE EPM_USERS
	ADD FOREIGN KEY EPM_USERS_FK03 (authenticationServiceId)
	REFERENCES EPM_AUTHENTICATIONSERVICES(id);

INSERT INTO EPM_PERMISSIONS (name, description) VALUES
    ('manageUserGroups', 'User can manage user groups.'),
    ('manageApplicationConfig', 'User can manage EndPoint Monitor configuration.'),
    ('manageUsers', 'User can manage user accounts.'),
    ('manageDashboardGroups', 'User can manage Dashboard Groups.'),
    ('manageCheckHosts', 'User can manage list of hosts checks can run on.'),
    ('manageMaintenancePeriods', 'User can manage check maintenance periods.'),
    ('manageChecks', 'User can override checks or check groups into maintenance mode.'),
    ('overrideMaintenance', 'User can override checks into and out of maintenance mode.'),
    ('manageProxyHosts', 'User can manage proxies used by checks.'),
    ('viewAuditLogs', 'User can view application audit logs.'),
    ('viewCheckResults', 'User can view check result history for all checks.'),
    ('manageNotifications', 'User can configure warning and alert notifications sent.'),
    ('manageApiKeys', 'User can issue and manage API keys.');

INSERT INTO EPM_CHECKHOSTS (description, hostname, enabled, archived, type, lastCheckInTimestamp, lastUpdateTimestamp, lastUpdateUserId)
    VALUES ('Archive Check Host', '', false, true, 0, now(), now(), 0);
UPDATE EPM_CHECKHOSTS SET id = 0 WHERE description = 'Archive Check Host';
INSERT INTO EPM_DASHBOARDGROUPS (name, description, archived, lastUpdateUserId)
    VALUES ('Archived Checks', 'Cluster for archived checks.', true, 0);
UPDATE EPM_DASHBOARDGROUPS SET id = 0 WHERE name = 'Archived Checks';
INSERT INTO EPM_CHECKGROUPS (name, description, dashboardGroupId, archived, lastUpdateUserId)
    VALUES ('Archived Check Group', 'Archived Check Group', 0, true, 0);
UPDATE EPM_CHECKGROUPS SET id = 0 WHERE name = 'Archived Check Group';


GRANT SELECT, INSERT, UPDATE, DELETE ON endPointMonitor.* TO 'endPointMonitorUser'@'%';
FLUSH PRIVILEGES;

INSERT INTO EPM_CONTROLLERS (path) VALUES
    ('/audit/logEntries.json'),
    ('/audit/allModules.json'),
    ('/config/allAuthenticationServiceTypes.json'),
    ('/config/createAuthenticationService'),
    ('/config/allAuthenticationServices.json'),
    ('/config/updateAuthenticationService'),
    ('/config/removeAuthenticationService'),
    ('/config/getAuthenticationServiceById.json'),
    ('/userManagement/createUser'),
    ('/userManagement/updateUser'),
    ('/userManagement/deleteUser'),
    ('/userManagement/allUsers.json'),
    ('/userManagement/getAllUserGroups.json'),
    ('/config/allPermissions.json'),
    ('/config/allUserGroups.json'),
    ('/config/createUserGroup'),
    ('/config/updateUserGroup'),
    ('/userManagement/clearUserMFAKey'),
    ('/userManagement/getUserById'),
    ('/config/getUserGroupById.json'),
    ('/userManagement/updateOwnPassword'),
    ('/userManagement/generateNewMFAKey'),
    ('/userManagement/registerMFAKey'),
    ('/config/removeUserGroup'),
    ('/config/allCheckHosts.json'),
    ('/config/dashboardGroups/searchAll'),
    ('/config/createCheckHost'),
    ('/config/getCheckHostById.json'),
    ('/config/updateCheckHost'),
    ('/config/removeCheckHost'),
    ('/config/dashboardGroups/create'),
    ('/config/dashboardGroups/getById'),
    ('/config/dashboardGroups/update'),
    ('/config/dashboardGroups/remove'),
    ('/config/allMaintenancePeriods.json'),
    ('/config/updateMaintenancePeriod'),
    ('/config/createMaintenancePeriod'),
    ('/config/getMaintenancePeriodById.json'),
    ('/config/removeMaintenancePeriod'),
    ('/config/allProxyHosts.json'),
    ('/config/getProxyHostById.json'),
    ('/config/createProxyHost'),
    ('/config/updateProxyHost'),
    ('/config/removeProxyHost'),
    ('/config/checkGroups/searchAll'),
    ('/config/checkGroups/getById'),
    ('/config/checkGroups/create'),
    ('/config/checkGroups/update'),
    ('/config/checkGroups/remove'),
    ('/config/allChecks.json'),
    ('/config/allCheckTypes.json'),
    ('/config/getCheckById.json'),
    ('/config/createCheck'),
    ('/config/updateCheck'),
    ('/config/removeCheck'),
    ('/config/setCheckEnabledStatus'),
    ('/config/setCheckMaintenanceOverrideFlag'),
    ('/config/setCheckGroupChecksEnabledState'),
    ('/config/setCheckGroupMaintenanceOverride'),
    ('/config/appClusterEmailAddresses.json'),
    ('/config/dashboardGroups/updateEmailAddresses'),
    ('/data/dashboard/getCheckResultHistoryById.json'),
    ('/data/dashboard/getCheckGroupResultHistoryById'),
    ('/reporting/getCheckResponseTimes.json'),
    ('/reporting/getWebPageCheckNetworkRequestCounts.json'),
    ('/config/checkWebJourneySteps.json'),
    ('/config/getWebJourneyStepById.json'),
    ('/config/updateWebJourneyStep'),
    ('/config/createWebJourneyStep'),
    ('/config/removeWebJourneyStep'),
    ('/reporting/getWebJourneyStepResults.json'),
    ('/reporting/getWebJourneyNetworkStatusCounts.json'),
    ('/reporting/getWebJourneyCommonFailedNetworkRequests.json'),
    ('/config/dashboardGroups/search'),
    ('/config/checkGroups/search'),
    ('/config/searchChecks'),
    ('/config/searchCheckHosts'),
    ('/config/searchProxyHosts'),
    ('/userManagement/searchUserGroups'),
    ('/data/dashboard/webJourneyStepResults'),
    ('/data/dashboard/screenshots'),
    ('/data/dashboard/webJourneyCapturedDOM'),
    ('/data/dashboard/webJourneyStepResults/networkRequests'),
    ('/data/dashboard/webJourneyStepResults/consoleLogs'),
    ('/notifications'),
    ('/userManagement/updateSettings'),
    ('/config/allApplicationConfig'),
    ('/config/databaseConfig'),
    ('/config/updateDatabaseConfig'),
    ('/config/updateApplicationConfig'),
    ('/config/disableSetup'),
    ('/config/searchPermissions'),
    ('/config/searchAuthenticationServices'),
    ('/config/generateAgentKeyPair'),
    ('/reporting/checkStatusPercentages.json'),
    ('/config/getCommonWebJourneySteps'),
    ('/config/getCommonWebJourneyStep'),
    ('/config/createCommonWebJourneyStep'),
    ('/config/updateCommonWebJourneyStep'),
    ('/config/removeCommonWebJourneyStep'),
    ('/config/searchCommonWebJourneySteps'),
    ('/config/authService/basicConfig'),
    ('/config/check/runNow'),
    ('/config/checks/export'),
    ('/config/checks/import'),
    ('/config/notifications/getById'),
    ('/config/notifications/search'),
    ('/config/notifications/create'),
    ('/config/notifications/update'),
    ('/config/notifications/remove'),
    ('/checks/checkTypes/search'),
    ('/config/apiKeys/getById'),
    ('/config/apiKeys/search'),
    ('/config/apiKeys/create'),
    ('/config/apiKeys/update'),
    ('/config/apiKeys/remove'),
    ('/config/hostGroups/search'),
    ('/config/hostGroups/hostGroup'),
    ('/config/hostGroups/create'),
    ('/config/hostGroups/update'),
    ('/config/hostGroups/remove'),
    ('/config/searchCheckHostsWithGroups'),
    ('/data/dashboard/dashboardGroup/checks'),
    ('/data/dashboard/dashboardGroupStatuses'),
    ('/data/dashboard/dashboardGroupCheckStatuses'),
    ('/config/checks/webJourney/convertToCommon'),
    ('/config/getCommonAndroidJourneySteps'),
    ('/config/getCommonAndroidJourneyStep'),
    ('/config/createCommonAndroidJourneyStep'),
    ('/config/updateCommonAndroidJourneyStep'),
    ('/config/removeCommonAndroidJourneyStep'),
    ('/config/searchCommonAndroidJourneySteps'),
    ('/config/checks/androidJourney/convertToCommon');

INSERT INTO EPM_CONTROLLERPERMISSIONS VALUES
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/audit/logEntries.json'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'viewAuditLogs')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/audit/allModules.json'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'viewAuditLogs')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/allAuthenticationServiceTypes.json'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageApplicationConfig')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/createAuthenticationService'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageApplicationConfig')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/allAuthenticationServices.json'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageApplicationConfig')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/allAuthenticationServices.json'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageUsers')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/updateAuthenticationService'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageApplicationConfig')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/removeAuthenticationService'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageApplicationConfig')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/getAuthenticationServiceById.json'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageApplicationConfig')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/userManagement/createUser'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageUsers')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/userManagement/updateUser'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageUsers')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/userManagement/deleteUser'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageUsers')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/userManagement/allUsers.json'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageUsers')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/allPermissions.json'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageUserGroups')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/allUserGroups.json'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageUserGroups')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/allUserGroups.json'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageDashboardGroups')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/allUserGroups.json'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageUsers')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/createUserGroup'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageUserGroups')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/updateUserGroup'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageUserGroups')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/removeUserGroup'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageUserGroups')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/userManagement/clearUserMFAKey'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageUsers')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/userManagement/getUserById'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageUsers')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/getUserGroupById.json'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageUserGroups')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/allCheckHosts.json'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageDashboardGroups')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/allCheckHosts.json'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageChecks')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/allCheckHosts.json'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageCheckHosts')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/dashboardGroups/searchAll'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageDashboardGroups')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/dashboardGroups/searchAll'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageChecks')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/createCheckHost'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageCheckHosts')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/getCheckHostById.json'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageCheckHosts')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/updateCheckHost'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageCheckHosts')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/removeCheckHost'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageCheckHosts')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/dashboardGroups/create'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageDashboardGroups')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/dashboardGroups/getById'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageDashboardGroups')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/dashboardGroups/update'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageDashboardGroups')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/dashboardGroups/remove'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageDashboardGroups')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/allMaintenancePeriods.json'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageMaintenancePeriods')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/updateMaintenancePeriod'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageMaintenancePeriods')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/createMaintenancePeriod'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageMaintenancePeriods')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/getMaintenancePeriodById.json'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageMaintenancePeriods')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/removeMaintenancePeriod'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageMaintenancePeriods')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/allProxyHosts.json'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageChecks')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/allProxyHosts.json'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageProxyHosts')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/getProxyHostById.json'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageProxyHosts')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/createProxyHost'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageProxyHosts')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/updateProxyHost'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageProxyHosts')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/removeProxyHost'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageProxyHosts')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/checkGroups/searchAll'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageChecks')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/checkGroups/getById'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageChecks')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/checkGroups/create'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageChecks')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/checkGroups/update'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageChecks')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/checkGroups/remove'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageChecks')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/allChecks.json'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageChecks')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/allChecks.json'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageMaintenancePeriods')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/allCheckTypes.json'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageChecks')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/getCheckById.json'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageChecks')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/createCheck'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageChecks')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/updateCheck'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageChecks')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/removeCheck'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageChecks')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/setCheckEnabledStatus'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageChecks')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/setCheckMaintenanceOverrideFlag'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageChecks')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/setCheckMaintenanceOverrideFlag'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'overrideMaintenance')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/setCheckGroupChecksEnabledState'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageChecks')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/setCheckGroupMaintenanceOverride'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageChecks')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/appClusterEmailAddresses.json'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageDashboardGroups')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/dashboardGroups/updateEmailAddresses'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageDashboardGroups')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/data/dashboard/getCheckResultHistoryById.json'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'viewCheckResults')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/data/dashboard/getCheckGroupResultHistoryById'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'viewCheckResults')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/reporting/getCheckResponseTimes.json'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'viewCheckResults')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/reporting/getWebPageCheckNetworkRequestCounts.json'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'viewCheckResults')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/checkWebJourneySteps.json'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageChecks')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/getWebJourneyStepById.json'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageChecks')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/updateWebJourneyStep'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageChecks')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/createWebJourneyStep'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageChecks')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/removeWebJourneyStep'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageChecks')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/reporting/getWebJourneyStepResults.json'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'viewCheckResults')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/reporting/getWebJourneyNetworkStatusCounts.json'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'viewCheckResults')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/reporting/getWebJourneyCommonFailedNetworkRequests.json'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'viewCheckResults')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/dashboardGroups/search'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageChecks')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/dashboardGroups/search'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageMaintenancePeriods')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/checkGroups/search'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageChecks')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/checkGroups/search'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageMaintenancePeriods')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/searchChecks'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageMaintenancePeriods')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/searchCheckHosts'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageChecks')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/searchProxyHosts'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageChecks')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/searchProxyHosts'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageApplicationConfig')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/searchProxyHosts'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageNotifications')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/userManagement/searchUserGroups'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageChecks')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/userManagement/searchUserGroups'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageUsers')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/data/dashboard/webJourneyStepResults'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'viewCheckResults')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/data/dashboard/screenshots'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'viewCheckResults')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/data/dashboard/webJourneyCapturedDOM'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'viewCheckResults')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/data/dashboard/webJourneyStepResults/networkRequests'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'viewCheckResults')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/data/dashboard/webJourneyStepResults/consoleLogs'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'viewCheckResults')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/notifications'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'viewCheckResults')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/userManagement/updateSettings'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageApplicationConfig')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/allApplicationConfig'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageApplicationConfig')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/databaseConfig'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageApplicationConfig')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/updateDatabaseConfig'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageApplicationConfig')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/updateApplicationConfig'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageApplicationConfig')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/disableSetup'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageApplicationConfig')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/searchPermissions'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageUserGroups')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/searchAuthenticationServices'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageUsers')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/generateAgentKeyPair'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageCheckHosts')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/reporting/checkStatusPercentages.json'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'viewCheckResults')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/getCommonWebJourneySteps'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageChecks')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/getCommonWebJourneyStep'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageChecks')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/createCommonWebJourneyStep'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageChecks')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/updateCommonWebJourneyStep'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageChecks')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/removeCommonWebJourneyStep'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageChecks')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/searchCommonWebJourneySteps'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageChecks')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/authService/basicConfig'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageUsers')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/check/runNow'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageChecks')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/checks/export'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageChecks')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/checks/import'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageChecks')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/notifications/getById'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageNotifications')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/notifications/search'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageNotifications')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/notifications/create'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageNotifications')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/notifications/update'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageNotifications')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/notifications/remove'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageNotifications')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/checks/checkTypes/search'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageNotifications')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/apiKeys/getById'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageApiKeys')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/apiKeys/search'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageApiKeys')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/apiKeys/create'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageApiKeys')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/apiKeys/update'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageApiKeys')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/apiKeys/remove'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageApiKeys')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/hostGroups/search'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageCheckHosts')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/hostGroups/hostGroup'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageCheckHosts')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/hostGroups/create'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageCheckHosts')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/hostGroups/update'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageCheckHosts')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/hostGroups/remove'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageCheckHosts')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/searchCheckHostsWithGroups'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageChecks')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/data/dashboard/dashboardGroup/checks'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'viewCheckResults')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/data/dashboard/dashboardGroupStatuses'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'viewCheckResults')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/data/dashboard/dashboardGroupCheckStatuses'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'viewCheckResults')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/checks/webJourney/convertToCommon'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageChecks')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/getCommonAndroidJourneySteps'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageChecks')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/getCommonAndroidJourneyStep'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageChecks')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/createCommonAndroidJourneyStep'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageChecks')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/updateCommonAndroidJourneyStep'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageChecks')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/removeCommonAndroidJourneyStep'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageChecks')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/searchCommonAndroidJourneySteps'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageChecks')),
((SELECT id FROM EPM_CONTROLLERS WHERE path = '/config/checks/androidJourney/convertToCommon'), (SELECT id FROM EPM_PERMISSIONS WHERE name = 'manageChecks'));

INSERT INTO EPM_CONTROLLERPERMISSIONS
    SELECT (SELECT id FROM EPM_CONTROLLERS WHERE path = '/userManagement/getAllUserGroups.json'), id FROM EPM_PERMISSIONS;
INSERT INTO EPM_CONTROLLERPERMISSIONS
    SELECT (SELECT id FROM EPM_CONTROLLERS WHERE path = '/userManagement/updateOwnPassword'), id FROM EPM_PERMISSIONS;
INSERT INTO EPM_CONTROLLERPERMISSIONS
    SELECT (SELECT id FROM EPM_CONTROLLERS WHERE path = '/userManagement/generateNewMFAKey'), id FROM EPM_PERMISSIONS;
INSERT INTO EPM_CONTROLLERPERMISSIONS
    SELECT (SELECT id FROM EPM_CONTROLLERS WHERE path = '/userManagement/registerMFAKey'), id FROM EPM_PERMISSIONS;

INSERT INTO EPM_DATABASE(name, type, stringValue, lastUpdateTimestamp)
    VALUES('previousVersion', 'string', '0.4.1.0', now());
COMMIT;
